# OpenDR Speech Recognition - Quadratic Self-organized neural network

This folder contains the OpenDR learner based on Quadratic Self-ONN implementation.

## Sources

The algorithm files were written from scratch based on the paper [Speech Command Recognition in Computationally Constrained Environments with a Quadratic Self-organized Operational Layer](https://arxiv.org/abs/2011.11436).